<?php
namespace Controller;

use Util\InstanceProvider;
use Util\Messages;
use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class Budget extends Simple {

    public function budgetItems(Request\Filter $request, Response $response) {
        try{
            $filter = $request->getFilterCriteria()->getConditions();
            $notClassificationId = Utilities::getValueInFilterDataSourceByName($filter,'NOT_CLASSIFICATION',true);
            $page = $request->getFilterCriteria()->getPage();
            $pageSize = $request->getFilterCriteria()->getPageSize();
            $budgetItems = InstanceProvider::getService()->getBudget()->budgetItem($filter,$page,$pageSize,$notClassificationId);
            Utilities::setDataSetDefault($request,$response,$budgetItems);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function issueBudget(Request\Filter $request, Response $response) {
        try{
            $conditions = $request->getFilterCriteria()->getConditions();
            $issueId = \Zeedhi\DevOps\Util\Utilities::getValueInFilterDataSourceByName($conditions,'ISSUE');
            $nameProposal = \Zeedhi\DevOps\Util\Utilities::getValueInFilterDataSourceByName($conditions,'NAME_PROPOSAL');
            $nameDiscount = \Zeedhi\DevOps\Util\Utilities::getValueInFilterDataSourceByName($conditions,'NAME_DISCOUNT');
            $namePercent = \Zeedhi\DevOps\Util\Utilities::getValueInFilterDataSourceByName($conditions,'NAME_PERCENT');
            $budget = InstanceProvider::getService()->getBudget()->findIssueBudget($issueId,$nameProposal,
                $nameDiscount,$namePercent);
            \Zeedhi\DevOps\Util\Utilities::setDataSetDefault($request,$response,$budget);
        } catch(\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }

    public function issueBudgetSave(Request\DataSet $request, Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();
            InstanceProvider::getService()->getBudget()->issueBudgetSave($rows);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }

    public function classificationBudgetItem(Request\Filter $request, Response $response) {
        try{
            $filter = $request->getFilterCriteria()->getConditions();
            $classificationId = Utilities::getValueInFilterDataSourceByName($filter,'CLASSIFICATION',true);
            $page = $request->getFilterCriteria()->getPage();
            $pageSize = $request->getFilterCriteria()->getPageSize();
            $budgetItems = InstanceProvider::getService()->getBudget()->classificationBudgetItem($classificationId,$filter,$page,$pageSize);
            Utilities::setDataSetDefault($request,$response,$budgetItems);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function classificationBudgetItemRemove(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $id = $row['ID'];
            InstanceProvider::getService()->getBudget()->classificationBudgetItemRemove($id);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function budgetItemSave(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $id = $row['ID'];
            $name = $row['NAME'];
            $valueItem = $row['VALUE_ITEM'];
            $unitMeasure = $row['UNIT_MEASURE'];
            $status = $row['STATUS'];

            $budgetItemId = InstanceProvider::getService()->getBudget()->budgetItemSave($id,$name,$valueItem,
                $unitMeasure,$status);

            Utilities::setDataSetDefault($request,$response,[$budgetItemId]);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function budgetItemRemove(Request\DataSet $request, Response $response) {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $id = $row['ID'];
            InstanceProvider::getService()->getBudget()->budgetItemRemove($id);
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function addBudgetItemInClassificationSave(Request\DataSet $request, Response $response) {
        try{
            $dataSet = array();
            $rows = $request->getDataSet()->getRows();
            foreach ($rows as $row) {
                $id = $row['ID'];
                $classification = $row['CLASSIFICATION'];
                $dataSet[] = InstanceProvider::getService()->getBudget()
                    ->addBudgetItemInClassificationSave($id,$classification);
            }
            Utilities::setDataSetDefault($request,$response,$dataSet);

        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}