<?php
namespace Service;

use Doctrine\ORM\EntityManager;
use \Util\Utilities;
use Zeedhi\DevOps\Model\Projectmanagement\Repositories;

/**
 * Class StructureType
 *
 * @package Service
 */
class CommentType {

    /** @var EntityManager $entityManager */
    protected $entityManager;
    /** @var  Repositories\CommentType $resourceRepository */
    protected $commentTypeRepository;
    /** @var  \Factory\CommentType $commentTypeFactory */
    protected $commentTypeFactory;

	public function __construct(EntityManager $entityManager, \Factory\CommentType $commentTypeFactory, \Util\Utilities $environment) {
            $this->entityManager = $entityManager;
            $this->commentTypeRepository = $this->entityManager->getRepository(Utilities::ENTITY_DIR . 'CommentType');
            $this->commentTypeFactory = $commentTypeFactory;
            $this->environment = $environment;
	}

    public function findCommentType($filter) {
       return $this->commentTypeRepository->findCommentType($filter);
    }

    public function saveCommentType($id, $name, $control, $attachmentRequired, $commentDescription){
        $connection = $this->entityManager->getConnection();
        try {
            $this->entityManager->beginTransaction();
            $organizationId = $this->environment->getCurrentOrganizationId();
            $commentType = $this->commentTypeRepository->findOneBy(array('id' => $id));
            $commentType = $this->commentTypeFactory->saveCommentType($commentType, $name, $control, $attachmentRequired,
                $organizationId, $commentDescription);
            $this->entityManager->persist($commentType);
            $this->entityManager->flush();
            $connection->commit();
        } catch(\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function removeCommentType($id) {
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $commentType = $this->commentTypeRepository->findOneBy(array('id' => $id));
            $this->entityManager->remove($commentType);

            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

} 